pub struct DetailItem {
pub kind: DetailKind,
pub content: MessageContent,
pub location: Option<SourceInfo>,
}Expand description
A detail item in a diagnostic message.
Following tidyverse guidelines, details provide specific information about the error (what went wrong, where, with what values).
Fields
kind: DetailKindThe kind of detail (error, info, note)
content: MessageContentThe content of the detail
location: Option<SourceInfo>Optional source location for this detail
When present, this identifies where in the source code this detail applies. This allows error messages to highlight multiple related locations.